aboutsummaryrefslogtreecommitdiffstats
path: root/activemodel/lib
diff options
context:
space:
mode:
authorSantiago Pastorino <santiago@wyeworks.com>2014-08-07 09:13:24 -0300
committerSantiago Pastorino <santiago@wyeworks.com>2014-08-07 09:13:24 -0300
commite2689d1dad9ea824ace78eca326e9e6ecc892bfc (patch)
tree6e814fd5a6023c6fb543934c26c8c046c98a6eb9 /activemodel/lib
parentf0fdba8b1d9f100d67494746acbb84e5a20f5729 (diff)
parentf8dcb365dfb8506c60297a4434f70f41b5259250 (diff)
downloadrails-e2689d1dad9ea824ace78eca326e9e6ecc892bfc.tar.gz
rails-e2689d1dad9ea824ace78eca326e9e6ecc892bfc.tar.bz2
rails-e2689d1dad9ea824ace78eca326e9e6ecc892bfc.zip
Merge pull request #16412 from yevhene/master
Fix in has_secure_password for passwords containing only spaces.
Diffstat (limited to 'activemodel/lib')
-rw-r--r--activemodel/lib/active_model/secure_password.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/activemodel/lib/active_model/secure_password.rb b/activemodel/lib/active_model/secure_password.rb
index 7e179cf4b7..f6ad35769f 100644
--- a/activemodel/lib/active_model/secure_password.rb
+++ b/activemodel/lib/active_model/secure_password.rb
@@ -105,7 +105,7 @@ module ActiveModel
attr_reader :password
# Encrypts the password into the +password_digest+ attribute, only if the
# new password is not blank.
#
# class User < ActiveRecord::Base
# has_secure_password validations: false
@@ -119,7 +119,7 @@ module ActiveModel
def password=(unencrypted_password)
if unencrypted_password.nil?
self.password_digest = nil
- elsif unencrypted_password.present?
+ elsif !unencrypted_password.empty?
@password = unencrypted_password
cost = ActiveModel::SecurePassword.min_cost ? BCrypt::Engine::MIN_COST : BCrypt::Engine.cost
self.password_digest = BCrypt::Password.create(unencrypted_password, cost: cost)
@@ -105,7 +105,7 @@ module ActiveModel
attr_reader :password
# Encrypts the password into the +password_digest+ attribute, only if the
- # new password is not blank.
+ # new password is not empty.
#
# class User < ActiveRecord::Base